@@ -37,26 +37,20 @@
 #include <sys/un.h>
 #include <glib.h>
 #include <gmodule.h>
-#if HAVE_IRDA
+#ifdef HAVE_IRDA
 #include <linux/types.h>
 #include <linux/irda.h>
 #endif
 #include "irmc_obex.h"
 #include "irmc_sync.h"
-#include "irmc_bluetooth.h"
-#if HAVE_BT_OBEX
-#include <bluetooth/bluetooth.h>
-#endif
 
 #include <openobex/obex.h>
 
 #define DISC_BUF_LEN	sizeof(struct irda_device_list) + \
 			sizeof(struct irda_device_info) * (10)
 
-extern gboolean multisync_debug;
-
 gint obex_irda_connect(obex_t *handle, gpointer ud) {
-#if HAVE_IRDA
+#ifdef HAVE_IRDA
   struct irda_device_list *list;
   unsigned char buf[DISC_BUF_LEN];
   int len;
@@ -141,7 +135,7 @@ gint obex_irda_disconnect(obex_t *handle, gpointer ud) {
 }
 
 GList* find_irda_units(irmc_config *config) {
-#if HAVE_IRDA
+#ifdef HAVE_IRDA
   struct irda_device_list *list;
   unsigned char buf[DISC_BUF_LEN];
 //int ret = -1; // unused!
