@@ -4,11 +4,11 @@
 #include <glib.h>
 #include <stdlib.h>
 #include <sys/socket.h>
-#if HAVE_IRDA
+#ifdef HAVE_IRDA
 #include <linux/types.h>
 #include <linux/irda.h>
 #endif
-#if HAVE_BLUETOOTH
+#ifdef HAVE_BLUETOOTH
 #include <bluetooth/bluetooth.h>
 #endif
 #include <openobex/obex.h>
@@ -33,12 +33,6 @@ typedef enum {
 
 typedef struct  {
   char *serial_number;
-  unsigned int calendar_changecounter;
-  char *calendar_dbid;
-  unsigned int addressbook_changecounter;
-  char *addressbook_dbid;
-  unsigned int notebook_changecounter;
-  char *notebook_dbid;
 
   obex_t obexhandle;             // Handle to the obex connection
 
@@ -46,7 +40,7 @@ typedef struct  {
   connect_medium connectmedium;  // The connection type
 
   // bluetooth specific
-  struct bt_unit btunit;         // Bluetooth address
+  bdaddr_t bdaddr;               // Bluetooth address
   int btchannel;                 // Bluetooth channel
 
   // cable specific
@@ -55,7 +49,7 @@ typedef struct  {
 
   // irda specific
   irmc_ir_unit irunit;           // IR device name and serial
-#if HAVE_IRDA
+#ifdef HAVE_IRDA
   __u32 ir_addr;                 // Absolute address to IR device (used temporary)
 #endif
 
@@ -64,10 +58,20 @@ typedef struct  {
 } irmc_config;
 
 typedef struct irmc_environment {
-  OSyncMember *member;           // The member of this environment
+  char *anchor_path;             // The path of the irmc anchor
   irmc_config config;            // The configuration
+  GList *databases;		 // List of irmc_datase
+  osync_bool isConnected;
 } irmc_environment;
 
+typedef struct irmc_database {
+  OSyncObjFormat *objformat;     // The configured objformat for this database
+  OSyncObjTypeSink *sink;
+  unsigned int changecounter;   
+  char *dbid;
+  char *obex_db;
+} irmc_database;
+
 obex_t* irmc_obex_client(irmc_config *config);
 char* sync_connect_get_serial(irmc_config *config);
 gboolean detect_slowsync(int changecounter, char *object, char **dbid, char **serial_number,
